WITH Ada.Text_IO;
WITH Ada.Float_Text_IO;
PROCEDURE Balloon_Drop IS
--------------------------------------------------------------
--| Simulates the travel of a water balloon from the top of
--| a building.
--| Author: M. B. Feldman, The George Washington University
--| Last Modified: August 1998
--------------------------------------------------------------

  SUBTYPE NonNegFloat IS Float RANGE 0.0 .. Float'Last;

  g : CONSTANT NonNegFloat := 9.80665;
                                 -- gravitational constant

  BuildingHeight:  NonNegFloat;  -- input - height of building
  DeltaT: NonNegFloat;           -- input - time interval

  Height: Float;                 -- output - height of balloon
  ElapsedTime: NonNegFloat;      -- output - elapsed time

BEGIN -- Balloon_Drop

  -- Enter building height and time interval.
  Ada.Text_IO.Put(Item => "Building height in meters > ");
  Ada.Float_Text_IO.Get(Item => BuildingHeight);
  Ada.Text_IO.Put (Item => "Time in seconds between table lines > ");
  Ada.Float_Text_IO.Get(Item => DeltaT);
  Ada.Text_IO.New_Line(Spacing => 2);

  -- Display balloon height until it hits the ground.
  Ada.Text_IO.Put(Item => "        Time      Height");
  Ada.Text_IO.New_Line;

  ElapsedTime := 0.0;
  Height := BuildingHeight;      -- initialize

  LOOP
    EXIT WHEN Height <= 0.0;
    Ada.Float_Text_IO.Put
      (Item => ElapsedTime, Fore => 8, Aft => 3, Exp => 0);
    Ada.Float_Text_IO.Put
      (Item => Height, Fore => 8, Aft => 3, Exp => 0);
    Ada.Text_IO.New_Line;
    ElapsedTime := ElapsedTime + DeltaT;
    Height := BuildingHeight - 0.5 * g * (ElapsedTime ** 2);
  END LOOP;

  -- Balloon hits the ground.
  Ada.Text_IO.New_Line;
  Ada.Text_IO.Put(Item => "SPLATT!!!");
  Ada.Text_IO.New_Line;

END Balloon_Drop;


